@@ -1,28 +1,28 @@
 use 5.12.0;
 use warnings;
-package Chess::960;
+package Chess::960 0.003;
 # ABSTRACT: a Chess960 starting position generator
-$Chess::960::VERSION = '0.002';
+
 use Carp ();
 
-# =head1 OVERVIEW
-#
-# L<Chess960|https://en.wikipedia.org/wiki/Chess960> is a chess variant invented
-# by Bobby Fischer, designed to somewhat reduce the value of memorization to
-# play, while retaining key properties of the game such as castling and one
-# bishop per color.
-#
-# Chess::960 generates random starting positions for a Chess960 game.
-#
-#   use Chess::960;
-#
-#   my $fen = Chess::960->new->fen; # Forsyth-Edwards notation of position
-#
-#   my $pos = Chess::960->new->generate_position; # simple data structure
-#
-#   my $pos = Chess::960->new->generate_position(123); # get position by number
-#
-# =cut
+#pod =head1 OVERVIEW
+#pod
+#pod L<Chess960|https://en.wikipedia.org/wiki/Chess960> is a chess variant invented
+#pod by Bobby Fischer, designed to somewhat reduce the value of memorization to
+#pod play, while retaining key properties of the game such as castling and one
+#pod bishop per color.
+#pod
+#pod Chess::960 generates random starting positions for a Chess960 game.
+#pod
+#pod   use Chess::960;
+#pod
+#pod   my $fen = Chess::960->new->fen; # Forsyth-Edwards notation of position
+#pod
+#pod   my $pos = Chess::960->new->generate_position; # simple data structure
+#pod
+#pod   my $pos = Chess::960->new->generate_position(123); # get position by number
+#pod
+#pod =cut
 
 my @BRIGHT = qw(1 3 5 7);
 my @DARK   = qw(0 2 4 6);
@@ -40,36 +40,36 @@ my @KNIGHTS = (
   [ 3, 4 ],
 );
 
-# =method new
-#
-# The constructor for Chess::960 does not, at present, take any argument.  In the
-# future, it may take arguments to pick different mappings between positions
-# and numbers.
-#
-# =cut
+#pod =method new
+#pod
+#pod The constructor for Chess::960 does not, at present, take any argument.  In the
+#pod future, it may take arguments to pick different mappings between positions
+#pod and numbers.
+#pod
+#pod =cut
 
 sub new {
   my ($class) = @_;
   bless {} => $class;
 }
 
-# =method generate_position
-#
-#   my $pos = $c960->generate_position($num);
-#
-# This returns a starting description, described by a hash.  If C<$num> is not
-# provided, a random position will be returned.  If a value for C<$num> that
-# isn't an integer between 0 and 959 is provided, an exception will be raised.
-#
-# Position 518 in the default mapping is the traditional chess starting position.
-#
-# The returned hashref has two entries:
-#
-#   number - the number of the generated position
-#   rank   - an eight-element arrayref giving the pieces' positions
-#            elements are characters in [BQNRK]
-#
-# =cut
+#pod =method generate_position
+#pod
+#pod   my $pos = $c960->generate_position($num);
+#pod
+#pod This returns a starting description, described by a hash.  If C<$num> is not
+#pod provided, a random position will be returned.  If a value for C<$num> that
+#pod isn't an integer between 0 and 959 is provided, an exception will be raised.
+#pod
+#pod Position 518 in the default mapping is the traditional chess starting position.
+#pod
+#pod The returned hashref has two entries:
+#pod
+#pod   number - the number of the generated position
+#pod   rank   - an eight-element arrayref giving the pieces' positions
+#pod            elements are characters in [BQNRK]
+#pod
+#pod =cut
 
 sub generate_position {
   my ($self, $num) = @_;
@@ -102,15 +102,15 @@ sub generate_position {
   return { number => $num, rank => \@rank };
 }
 
-# =method fen
-#
-# This method returns a
-# L<FEN|https://en.wikipedia.org/wiki/Forsyth%E2%80%93Edwards_Notation>-format
-# string describing the complete starting position of the board.  For example:
-#
-#   rnbbqkrn/pppppppp/8/8/8/8/PPPPPPPP/RNBBQKRN w KQkq - 0 1
-#
-# =cut
+#pod =method fen
+#pod
+#pod This method returns a
+#pod L<FEN|https://en.wikipedia.org/wiki/Forsyth%E2%80%93Edwards_Notation>-format
+#pod string describing the complete starting position of the board.  For example:
+#pod
+#pod   rnbbqkrn/pppppppp/8/8/8/8/PPPPPPPP/RNBBQKRN w KQkq - 0 1
+#pod
+#pod =cut
 
 sub fen {
   my ($self, $num) = @_;
@@ -140,7 +140,7 @@ Chess::960 - a Chess960 starting position generator
 
 =head1 VERSION
 
-version 0.002
+version 0.003
 
 =head1 OVERVIEW
 
@@ -159,6 +159,16 @@ Chess::960 generates random starting positions for a Chess960 game.
 
   my $pos = Chess::960->new->generate_position(123); # get position by number
 
+=head1 PERL VERSION
+
+This library should run on perls released even a long time ago.  It should work
+on any version of perl released in the last five years.
+
+Although it may work on older versions of perl, no guarantee is made that the
+minimum required version will not be increased.  The version may be increased
+for any reason, and there is no promise that patches will be accepted to lower
+the minimum required perl.
+
 =head1 METHODS
 
 =head2 new
@@ -193,7 +203,13 @@ string describing the complete starting position of the board.  For example:
 
 =head1 AUTHOR
 
-Ricardo Signes <rjbs@cpan.org>
+Ricardo Signes <cpan@semiotic.systems>
+
+=head1 CONTRIBUTOR
+
+=for stopwords Ricardo Signes
+
+Ricardo Signes <rjbs@semiotic.systems>
 
 =head1 COPYRIGHT AND LICENSE
 
